﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Schedules;
using System.ComponentModel;
using Infragistics.Windows.Reporting;

namespace SimpleGantt
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataContext = new XamGanttViewModel();

            var timescale = this.gantt.TimescaleResolved as Timescale;
            timescale.Bands[0].Unit = TimescaleUnit.Days;
            timescale.Bands[1].Unit = TimescaleUnit.Hours;

        }
        
    }

    public class XamGanttViewModel : INotifyPropertyChanged
    {
        private Project _project;
        public Project Project
        {
            get { return _project; }
            set
            {
                _project = value;
                NotifyPropertyChanged("Project");
            }
        }

        public XamGanttViewModel()
        {
            LoadDefaultProject();
        }

        private void LoadDefaultProject()
        {
            Project = new Project();

            var parent = new ProjectTask
            {
                TaskName = "Project Summary",
                IsManual = false,
            };

            Project.RootTask.Tasks.Add(parent);

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Create specification and requirements",
                IsManual = false,
                Start = DateTime.Today.AddHours(10).ToUniversalTime(),
                ManualDuration = ProjectDuration.FromFormatUnits(3, ProjectDurationFormat.Days),
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Create a demo",
                IsManual = true,
                Start = DateTime.Today.AddHours(3).ToUniversalTime(),
                Duration = TimeSpan.FromHours(16),
                IsEstimated = true,
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Implementation",
                IsManual = true,
                Start = DateTime.Today.AddHours(5).ToUniversalTime(),
                DurationText = "A couple Of days",
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Testings",
                IsManual = false,
                IsActive = false,
                Start = DateTime.Today.AddHours(2).ToUniversalTime(),
                Duration = TimeSpan.FromHours(12)
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "0 day Milestone",
                IsManual = false,
                Start = DateTime.Today.AddHours(11).ToUniversalTime(),
                Duration = TimeSpan.Zero
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "2 day Milestone",
                IsManual = false,
                IsMilestone = true,
                Start = DateTime.Today.AddHours(2).ToUniversalTime(),
                Duration = TimeSpan.FromHours(8 * 2)
            });
        }

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;
        protected void NotifyPropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion //INotifyPropertyChanged
    }


}
